@@ -22,12 +22,6 @@ def remove(ctx, env_name):
 
     for env_name in environments:
         environment = app.get_environment(env_name)
-
-        try:
-            environment.check_compatibility()
-        except Exception:  # noqa: BLE001, S112
-            continue
-
         if environment.exists() or environment.build_environment_exists():
             with app.status(f'Removing environment: {env_name}'):
                 environment.remove()
