@@ -471,8 +471,11 @@ class TemplateConfig(LazilyParsedConfig):
                     import subprocess
 
                     try:
-                        name = subprocess.check_output(['git', 'config', '--get', 'user.name'], text=True).strip()
-                    except Exception:
+                        name = subprocess.check_output(
+                            ['git', 'config', '--get', 'user.name'],  # noqa: S607
+                            text=True,
+                        ).strip()
+                    except Exception:  # noqa: BLE001
                         name = 'U.N. Owen'
 
                 self._field_name = self.raw_data['name'] = name
@@ -499,8 +502,11 @@ class TemplateConfig(LazilyParsedConfig):
                     import subprocess
 
                     try:
-                        email = subprocess.check_output(['git', 'config', '--get', 'user.email'], text=True).strip()
-                    except Exception:
+                        email = subprocess.check_output(
+                            ['git', 'config', '--get', 'user.email'],  # noqa: S607
+                            text=True,
+                        ).strip()
+                    except Exception:  # noqa: BLE001
                         email = 'void@some.where'
 
                 self._field_email = self.raw_data['email'] = email
@@ -520,11 +526,11 @@ class TemplateConfig(LazilyParsedConfig):
                 if not isinstance(licenses, dict):
                     self.raise_error('must be a table')
 
-                self._field_licenses = LicensesConfig(licenses, self.steps + ('licenses',))
+                self._field_licenses = LicensesConfig(licenses, (*self.steps, 'licenses'))
             else:
                 licenses = {}
                 self.raw_data['licenses'] = licenses
-                self._field_licenses = LicensesConfig(licenses, self.steps + ('licenses',))
+                self._field_licenses = LicensesConfig(licenses, (*self.steps, 'licenses'))
 
         return self._field_licenses
 
@@ -548,7 +554,7 @@ class TemplateConfig(LazilyParsedConfig):
                 self._field_plugins = plugins
             else:
                 self._field_plugins = self.raw_data['plugins'] = {
-                    'default': {'tests': True, 'ci': False, 'src-layout': False}
+                    'default': {'tests': True, 'ci': False, 'src-layout': True}
                 }
 
         return self._field_plugins
@@ -623,11 +629,11 @@ class TerminalConfig(LazilyParsedConfig):
                 if not isinstance(styles, dict):
                     self.raise_error('must be a table')
 
-                self._field_styles = StylesConfig(styles, self.steps + ('styles',))
+                self._field_styles = StylesConfig(styles, (*self.steps, 'styles'))
             else:
                 styles = {}
                 self.raw_data['styles'] = styles
-                self._field_styles = StylesConfig(styles, self.steps + ('styles',))
+                self._field_styles = StylesConfig(styles, (*self.steps, 'styles'))
 
         return self._field_styles
 
